@@ -21,7 +21,7 @@ from shade import exc
 from shade import _utils
 
 
-NON_CALLABLES = (six.string_types, bool, dict, int, list, type(None))
+NON_CALLABLES = (six.string_types, bool, dict, int, float, list, type(None))
 
 log = logging.getLogger(__name__)
 
@@ -56,18 +56,51 @@ def find_nova_addresses(addresses, ext_tag=None, key_name=None, version=4):
 
 
 def get_server_ip(server, **kwargs):
-    addrs = find_nova_addresses(server.addresses, **kwargs)
+    addrs = find_nova_addresses(server['addresses'], **kwargs)
     if not addrs:
         return None
     return addrs[0]
 
 
-def get_server_private_ip(server):
-    return get_server_ip(server, ext_tag='fixed', key_name='private')
+def get_server_private_ip(server, cloud=None):
+    """Find the private IP address
 
+    If Neutron is available, search for a port on a network where
+    `router:external` is False and `shared` is False. This combination
+    indicates a private network with private IP addresses. This port should
+    have the private IP.
 
-def get_server_public_ip(server):
-    return get_server_ip(server, ext_tag='floating', key_name='public')
+    If Neutron is not available, or something goes wrong communicating with it,
+    as a fallback, try the list of addresses associated with the server dict,
+    looking for an IP type tagged as 'fixed' in the network named 'private'.
+
+    Last resort, ignore the IP type and just look for an IP on the 'private'
+    network (e.g., Rackspace).
+    """
+    if cloud and cloud.has_service('network'):
+        try:
+            server_ports = cloud.search_ports(
+                filters={'device_id': server['id']})
+            nets = cloud.search_networks(
+                filters={'router:external': False, 'shared': False})
+        except Exception as e:
+            log.debug(
+                "Something went wrong talking to neutron API: "
+                "'{msg}'. Trying with Nova.".format(msg=str(e)))
+        else:
+            for net in nets:
+                for port in server_ports:
+                    if net['id'] == port['network_id']:
+                        for ip in port['fixed_ips']:
+                            if _utils.is_ipv4(ip['ip_address']):
+                                return ip['ip_address']
+
+    ip = get_server_ip(server, ext_tag='fixed', key_name='private')
+    if ip:
+        return ip
+
+    # Last resort, and Rackspace
+    return get_server_ip(server, key_name='private')
 
 
 def get_server_external_ipv4(cloud, server):
@@ -97,7 +130,7 @@ def get_server_external_ipv4(cloud, server):
             # Search a fixed IP attached to an external net. Unfortunately
             # Neutron ports don't have a 'floating_ips' attribute
             server_ports = cloud.search_ports(
-                filters={'device_id': server.id})
+                filters={'device_id': server['id']})
             ext_nets = cloud.search_networks(filters={'router:external': True})
         except Exception as e:
             log.debug(
@@ -126,7 +159,7 @@ def get_server_external_ipv4(cloud, server):
         return ext_ip
 
     # Try to find a globally routable IP address
-    for interfaces in server.addresses.values():
+    for interfaces in server['addresses'].values():
         for interface in interfaces:
             if _utils.is_ipv4(interface['addr']) and \
                     _utils.is_globally_routable_ipv4(interface['addr']):
@@ -173,21 +206,21 @@ def get_groups_from_server(cloud, server, server_vars):
     groups.append("%s_%s" % (cloud_name, region))
 
     # Check if group metadata key in servers' metadata
-    group = server.metadata.get('group')
+    group = server['metadata'].get('group')
     if group:
         groups.append(group)
 
-    for extra_group in server.metadata.get('groups', '').split(','):
+    for extra_group in server['metadata'].get('groups', '').split(','):
         if extra_group:
             groups.append(extra_group)
 
-    groups.append('instance-%s' % server.id)
+    groups.append('instance-%s' % server['id'])
 
     for key in ('flavor', 'image'):
         if 'name' in server_vars[key]:
             groups.append('%s-%s' % (key, server_vars[key]['name']))
 
-    for key, value in iter(server.metadata.items()):
+    for key, value in iter(server['metadata'].items()):
         groups.append('meta-%s_%s' % (key, value))
 
     az = server_vars.get('az', None)
@@ -207,7 +240,7 @@ def get_hostvars_from_server(cloud, server, mounts=None):
     # not exist to remain consistent with the pre-existing missing values
     server_vars['public_v4'] = get_server_external_ipv4(cloud, server) or ''
     server_vars['public_v6'] = get_server_external_ipv6(server) or ''
-    server_vars['private_v4'] = get_server_private_ip(server) or ''
+    server_vars['private_v4'] = get_server_private_ip(server, cloud) or ''
     if cloud.private:
         interface_ip = server_vars['private_v4']
     else:
@@ -225,18 +258,18 @@ def get_hostvars_from_server(cloud, server, mounts=None):
     server_vars['region'] = cloud.region_name
     server_vars['cloud'] = cloud.name
 
-    flavor_id = server.flavor['id']
+    flavor_id = server['flavor']['id']
     flavor_name = cloud.get_flavor_name(flavor_id)
     if flavor_name:
         server_vars['flavor']['name'] = flavor_name
     server_vars['flavor'].pop('links', None)
 
     # OpenStack can return image as a string when you've booted from volume
-    if str(server.image) == server.image:
-        image_id = server.image
+    if str(server['image']) == server['image']:
+        image_id = server['image']
         server_vars['image'] = dict(id=image_id)
     else:
-        image_id = server.image.get('id', None)
+        image_id = server['image'].get('id', None)
     if image_id:
         image_name = cloud.get_image_name(image_id)
         if image_name:
