@@ -20,6 +20,7 @@ Tests floating IP resource methods for Neutron and Nova-network.
 """
 
 from mock import patch
+import os_client_config
 from shade import meta
 from shade import OpenStackCloud
 from shade.tests.fakes import FakeServer
@@ -29,7 +30,8 @@ from shade.tests.unit import base
 class TestFloatingIP(base.TestCase):
     def setUp(self):
         super(TestFloatingIP, self).setUp()
-        self.client = OpenStackCloud("cloud", {})
+        config = os_client_config.OpenStackConfig()
+        self.client = OpenStackCloud(cloud_config=config.get_one_cloud())
 
     @patch.object(OpenStackCloud, 'get_floating_ip')
     @patch.object(OpenStackCloud, 'attach_ip_to_server')
@@ -62,7 +64,7 @@ class TestFloatingIP(base.TestCase):
     def test_add_ips_to_server_pool(
             self, mock_add_ip_from_pool, mock_nova_client):
         server = FakeServer(
-            id='server-id', name='test-server', status="ACTIVE", addresses={}
+            id='romeo', name='test-server', status="ACTIVE", addresses={}
         )
         server_dict = meta.obj_to_dict(server)
         pool = 'nova'
@@ -71,7 +73,7 @@ class TestFloatingIP(base.TestCase):
 
         self.client.add_ips_to_server(server_dict, ip_pool=pool)
 
-        mock_add_ip_from_pool.assert_called_with(server_dict, pool)
+        mock_add_ip_from_pool.assert_called_with('romeo', pool)
 
     @patch.object(OpenStackCloud, 'nova_client')
     @patch.object(OpenStackCloud, 'add_ip_list')
